@@ -23,10 +23,11 @@ units.
 import logging
 import os.path
 
-logger = logging.getLogger('giza.content.examples.inheritance')
+logger = logging.getLogger('giza.core.inheritance')
 
 from giza.config.base import RecursiveConfigurationBase, ConfigurationBase
 from giza.tools.serialization import ingest_yaml_list
+from giza.content.helper import level_characters, edition_check
 
 class InheritableContentError(Exception):
     """
@@ -57,7 +58,6 @@ class InheritableContentBase(RecursiveConfigurationBase):
         elif isinstance(value, dict):
             self.state['title'] = TitleData(value)
         else:
-            print value, type(value)
             raise TypeError
 
     @property
@@ -83,12 +83,11 @@ class InheritableContentBase(RecursiveConfigurationBase):
 
     def _is_resolveable(self, data):
         try:
-            return not self.is_resolved() and self.source.file in data
+            return not self.is_resolved() and self.source.file in data.cache
         except AttributeError:
             logger.warning(str(data) + ' is not resolvable')
             return False
 
-
     def resolve(self, data):
         if self._is_resolveable(data):
             try:
@@ -103,7 +102,7 @@ class InheritableContentBase(RecursiveConfigurationBase):
                 logger.error(e)
 
         if self.source is not None and not self.source.is_resolved():
-            m = 'cannot find {0} and ref {1} do not  exist'.format(self.source.file, self.source.ref)
+            m = 'cannot find {0} and ref "{1}" do not exist'.format(self.source.file, self.source.ref)
             logger.error(m)
             raise InheritableContentError(m)
 
@@ -130,24 +129,29 @@ class InheritanceReference(RecursiveConfigurationBase):
         else:
             raise TypeError('{0} is not boolean'.format(value))
 
+    def is_resolved(self):
+        return self.resolved
+
     @property
     def file(self):
         return self.state['file']
 
     @file.setter
     def file(self, value):
-        fns = [ value,
-                os.path.join(self.conf.paths.projectroot, value),
-                os.path.join(self.conf.paths.projectroot,
-                             self.conf.paths.includes, value) ]
+        if 'file' in self.state and os.path.exists(self.state['file']):
+            return
+
+        fns = set([ # value,  os.path.abspath(value),
+                   os.path.join(self.conf.paths.projectroot, value),
+                   os.path.join(self.conf.paths.projectroot,
+                                self.conf.paths.includes, value) ])
 
         try:
-            fns.append(os.path.join(self.conf.paths.projectroot,
+            fns.add(os.path.join(self.conf.paths.projectroot,
                                     self.conf.paths.source, value))
         except KeyError:
             pass
 
-
         for fn in fns:
             if os.path.exists(fn):
                 self.state['file'] = fn
@@ -204,20 +208,41 @@ class DataContentBase(RecursiveConfigurationBase):
             src = ingest_yaml_list(src)
 
         for doc in src:
-            self.add(doc)
+            if edition_check(doc, self.conf) is False:
+                continue
+            try:
+                self.add(doc)
+            except:
+                print(doc)
 
     def add(self, doc):
+        if 'ref' not in doc:
+            if 'source' in doc:
+                ref = doc['source']['ref']
+            elif 'inherit' in doc:
+                ref = doc['inherit']['ref']
+
+            doc['ref'] = ref
+
         if doc['ref'] not in self.content:
             if isinstance(doc, self.content_class):
-                self.content[doc['ref']] = doc
+                content = doc
             else:
                 try:
-                    self.content[doc['ref']] = self.content_class(doc)
+                    content = self.content_class(doc)
                 except TypeError:
-                    self.content[doc['ref']] = self.content_class(doc, self.conf)
+                    content = self.content_class(doc, self.conf)
+
+            self.content[content.ref] = content
+
+            if not content.is_resolved():
+                content.resolve(self.data)
+
+            return content
         else:
-            m = 'content named {0} already exists'.format(doc['ref'])
+            m = 'content named "{0}" already exists'.format(doc['ref'])
             logger.error(m)
+            logger.warning(doc)
             raise InheritableContentError(m)
 
     def fetch(self, ref):
@@ -225,7 +250,7 @@ class DataContentBase(RecursiveConfigurationBase):
             content = self.content[ref]
 
             if not content.is_resolved():
-                content.resolve(self.data)
+                content.resolve(self)
 
             return content
         else:
@@ -288,18 +313,29 @@ class DataCache(RecursiveConfigurationBase):
             data = ingest_yaml_list(fn)
             self.cache[fn] = self.content_class(data, self, self.conf)
         else:
-            logger.info('populated file {0} exists in the cache'.format(fn))
+            logger.debug('populated file {0} exists in the cache'.format(fn))
 
     def fetch(self, fn, ref):
         if fn not in self.cache:
             logger.error('file "{0}" is not included.'.format(fn))
             raise InheritableContentError
 
+        if self.cache[fn] == []:
+            self.add_file(fn)
+
         return self.cache[fn].fetch(ref)
 
 class TitleData(ConfigurationBase):
     _option_registry = ['text']
 
+    @property
+    def character(self):
+        return self.level
+
+    @character.setter
+    def character(self, value):
+        self.level = level_characters[value]
+
     @property
     def level(self):
         if 'level' not in self.state:
