@@ -24,8 +24,7 @@ import yaml
 logger = logging.getLogger('giza.scrumpy')
 
 from giza.config.jeerah import fetch_config, JeerahRuntimeStateConfig
-from giza.config.helper import dump_skel
-from giza.config.credentials import setup_credentials
+from giza.config.helper import dump_skel, setup_credentials
 from giza.cmdline import get_base_parser
 from giza.core.app import BuildApp
 from giza.jeerah.client import JeerahClient
@@ -189,7 +188,9 @@ def setup(args):
     dump_skel(skel, args)
 
 @argh.named('setup-credentials')
+@argh.arg('user_conf_path')
 def setup_credential_file(args):
+
     setup_credentials(args)
 
 #################### scrumpy entry point #####################
